@@ -17,15 +17,10 @@
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
  * @file globus_gass_transfer_request.c
+ * @brief GASS Transfer Request
  *
  * This module implements the request structure accessors for the
  * GASS transfer library 
- *
- * CVS Information:
- * $Source: /home/globdev/CVS/globus-packages/gass/transfer/source/library/globus_gass_transfer_request.c,v $
- * $Date: 2011/02/03 21:46:40 $
- * $Revision: 1.18 $
- * $Author: bester $
  */
 #endif
 
@@ -734,7 +729,7 @@ globus_i_gass_transfer_request_init(
     req->type			= type;
     req->status			= GLOBUS_GASS_TRANSFER_REQUEST_STARTING;
     req->referral_url		= GLOBUS_NULL;
-    req->referral_count		= GLOBUS_NULL;
+    req->referral_count		= 0;
     req->callback		= callback;
     req->callback_arg		= user_arg;
     req->proto			= GLOBUS_NULL;
@@ -772,7 +767,7 @@ globus_i_gass_transfer_request_init(
 					  (void *) req,
 					  2);
     globus_list_insert(&globus_i_gass_transfer_requests,
-		       (void *) (*request));
+		       (void *) (intptr_t) (*request));
     
     return;
 
@@ -831,7 +826,7 @@ globus_i_gass_transfer_request_destroy(
 	globus_list_t *				tmp;
 
 	tmp = globus_list_search(globus_i_gass_transfer_requests,
-				 (void *) request);
+				 (void *) (intptr_t) request);
 	
 #if DEBUG_GASS_TRANSFER
 	printf(_GTSL("removing from list\n"));
